==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/CircleCD/ts/CircleCD_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CircleCD</name>
    <message>
        <source>Center or radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Center lub promień</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź promień:
Promień:</translatorcomment>
        <translation type="obsolete">Promień:</translation>
    </message>
    <message>
        <source>Center, &amp;Radius</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Środek, &amp;promień</translatorcomment>
        <translation type="obsolete">Środek, &amp;promień</translation>
    </message>
    <message>
        <source>Draw circle from center and radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Narysuj koło od środka i promienia</translation>
    </message>
    <message>
        <location filename="../CircleCD.ui" line="+17"/>
        <location filename="../CircleCDDialog.ui" line="+89"/>
        <source>Diameter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <location filename="../CircleCDDialog.ui" line="-60"/>
        <source>Angle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CircleCDInit.js" line="+2"/>
        <source>Center, &amp;Diameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle from center and diameter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/CircleCD/ts/CircleCD_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CircleCD</name>
    <message>
        <source>Center or radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Center lub promień</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż środek
Łuk: środek, punkt, kąty</translatorcomment>
        <translation type="obsolete">Wyśrodkuj</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź promień:
Promień:</translatorcomment>
        <translation type="obsolete">Promień:</translation>
    </message>
    <message>
        <source>Center, &amp;Radius</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Środek, &amp;promień</translatorcomment>
        <translation type="obsolete">Środek, &amp;promień</translation>
    </message>
    <message>
        <source>Draw circle from center and radius</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Narysuj koło od środka i promienia</translation>
    </message>
    <message>
        <location filename="../CircleCD.ui" line="+17"/>
        <location filename="../CircleCDDialog.ui" line="+89"/>
        <source>Diameter:</source>
        <translation>Średnica:</translation>
    </message>
    <message>
        <location line="+33"/>
        <location filename="../CircleCDDialog.ui" line="-60"/>
        <source>Angle:</source>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation>Punkt odniesienia:</translation>
    </message>
    <message>
        <location filename="../CircleCDInit.js" line="+2"/>
        <source>Center, &amp;Diameter</source>
        <translation>Środek, ś&amp;rednica</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle from center and diameter</source>
        <translation>Rysuje okrąg ze środka i danej średnicy</translation>
    </message>
</context>
</TS>
